==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/kusto/kotlin/inputs/GetManagedPrivateEndpointPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.kusto.kotlin.inputs

import com.pulumi.azurenative.kusto.inputs.GetManagedPrivateEndpointPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property clusterName The name of the Kusto cluster.
 * @property managedPrivateEndpointName The name of the managed private endpoint.
 * @property resourceGroupName The name of the resource group containing the Kusto cluster.
 */
public data class GetManagedPrivateEndpointPlainArgs(
    public val clusterName: String,
    public val managedPrivateEndpointName: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.kusto.inputs.GetManagedPrivateEndpointPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.kusto.inputs.GetManagedPrivateEndpointPlainArgs =
        com.pulumi.azurenative.kusto.inputs.GetManagedPrivateEndpointPlainArgs.builder()
            .clusterName(clusterName.let({ args0 -> args0 }))
            .managedPrivateEndpointName(managedPrivateEndpointName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetManagedPrivateEndpointPlainArgs].
 */
@PulumiTagMarker
public class GetManagedPrivateEndpointPlainArgsBuilder internal constructor() {
    private var clusterName: String? = null

    private var managedPrivateEndpointName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The name of the Kusto cluster.
     */
    @JvmName("avceesgtxnyxypla")
    public suspend fun clusterName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.clusterName = mapped
    }

    /**
     * @param value The name of the managed private endpoint.
     */
    @JvmName("aygganpqudoxkxkq")
    public suspend fun managedPrivateEndpointName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.managedPrivateEndpointName = mapped
    }

    /**
     * @param value The name of the resource group containing the Kusto cluster.
     */
    @JvmName("bkoljibiixkpdowg")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetManagedPrivateEndpointPlainArgs = GetManagedPrivateEndpointPlainArgs(
        clusterName = clusterName ?: throw PulumiNullFieldException("clusterName"),
        managedPrivateEndpointName = managedPrivateEndpointName ?: throw
            PulumiNullFieldException("managedPrivateEndpointName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/kusto/kotlin/inputs/GetManagedPrivateEndpointPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.kusto.kotlin.inputs

import com.pulumi.azurenative.kusto.inputs.GetManagedPrivateEndpointPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property clusterName The name of the Kusto cluster.
 * @property managedPrivateEndpointName The name of the managed private endpoint.
 * @property resourceGroupName The name of the resource group containing the Kusto cluster.
 */
public data class GetManagedPrivateEndpointPlainArgs(
    public val clusterName: String,
    public val managedPrivateEndpointName: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.kusto.inputs.GetManagedPrivateEndpointPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.kusto.inputs.GetManagedPrivateEndpointPlainArgs =
        com.pulumi.azurenative.kusto.inputs.GetManagedPrivateEndpointPlainArgs.builder()
            .clusterName(clusterName.let({ args0 -> args0 }))
            .managedPrivateEndpointName(managedPrivateEndpointName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetManagedPrivateEndpointPlainArgs].
 */
@PulumiTagMarker
public class GetManagedPrivateEndpointPlainArgsBuilder internal constructor() {
    private var clusterName: String? = null

    private var managedPrivateEndpointName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The name of the Kusto cluster.
     */
    @JvmName("ufhqlepglsvuejxg")
    public suspend fun clusterName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.clusterName = mapped
    }

    /**
     * @param value The name of the managed private endpoint.
     */
    @JvmName("eyohacycbfshekpj")
    public suspend fun managedPrivateEndpointName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.managedPrivateEndpointName = mapped
    }

    /**
     * @param value The name of the resource group containing the Kusto cluster.
     */
    @JvmName("aybgxqatvviuucbp")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetManagedPrivateEndpointPlainArgs = GetManagedPrivateEndpointPlainArgs(
        clusterName = clusterName ?: throw PulumiNullFieldException("clusterName"),
        managedPrivateEndpointName = managedPrivateEndpointName ?: throw
            PulumiNullFieldException("managedPrivateEndpointName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}
